Class: CurationConcerns::CurationConcern

Inherits:
Object
  • Object
show all
Defined in:
app/services/curation_concerns/curation_concern.rb

Class Method Summary collapse

Class Method Details

.actor(curation_concern, current_user) ⇒ #create, #update

A consumer of this method can inject a different factory into this class in order to change the behavior of this method.



11
12
13
# File 'app/services/curation_concerns/curation_concern.rb', line 11

def self.actor(curation_concern, current_user)
  actor_factory.build(curation_concern, current_user)
end